@@ -52,6 +52,7 @@ __all__ = ('ez_mie',
            'mie_mu_with_uniform_cdf',
            )
 
+
 def _Lentz_Dn(z, N):
     """
     Compute the logarithmic derivative of the Ricatti-Bessel function.
@@ -83,6 +84,7 @@ def _Lentz_Dn(z, N):
 
     return -N / z + runratio
 
+
 def _D_downwards(z, N, D):
     """
     Compute the logarithmic derivative by downwards recurrence.
@@ -98,6 +100,7 @@ def _D_downwards(z, N, D):
         last_D = n / z - 1.0 / (last_D + n / z)
         D[n - 1] = last_D
 
+
 def _D_upwards(z, N, D):
     """
     Compute the logarithmic derivative by upwards recurrence.
@@ -113,6 +116,7 @@ def _D_upwards(z, N, D):
     for n in range(2, N):
         D[n] = 1 / (n / z - D[n - 1]) - n / z
 
+
 def _D_calc(m, x, N):
     """
     Compute the logarithmic derivative using best method.
@@ -129,12 +133,13 @@ def _D_calc(m, x, N):
     kappa = np.abs(m.imag)
     D = np.zeros(N, dtype=np.complex128)
 
-    if n < 1 or n > 10 or kappa > 10 or x*kappa >= 3.9 - 10.8 * n + 13.78 * n**2:
-        _D_downwards(m*x, N, D)
+    if n < 1 or n > 10 or kappa > 10 or x * kappa >= 3.9 - 10.8 * n + 13.78 * n**2:
+        _D_downwards(m * x, N, D)
     else:
-        _D_upwards(m*x, N, D)
+        _D_upwards(m * x, N, D)
     return D
 
+
 def _mie_An_Bn(m, x, a, b):
     """
     Compute arrays of Mie coefficients A and B for a sphere.
@@ -182,6 +187,7 @@ def _mie_An_Bn(m, x, a, b):
 
     return [a, b]
 
+
 def _small_conducting_mie(m, x):
     """
     Calculate the efficiencies for a small conducting spheres.
@@ -206,8 +212,10 @@ def _small_conducting_mie(m, x):
     ahat2 = complex(0.0, x**2 / 30.)
     bhat2 = complex(0.0, -x**2 / 45.)
 
-    qsca = x**4 * (6 * np.abs(ahat1)**2 + 6 * np.abs(bhat1)**2 + 10 * np.abs(ahat2)**2 +
-                   10 * np.abs(bhat2)**2)
+    qsca = x**4 * (6 * np.abs(ahat1)**2
+                   + 6 * np.abs(bhat1)**2
+                   + 10 * np.abs(ahat2)**2
+                   + 10 * np.abs(bhat2)**2)
     qext = qsca
     g = ahat1.imag * (ahat2.imag + bhat1.imag)
     g += bhat2.imag * (5.0 / 9.0 * ahat2.imag + bhat1.imag)
@@ -218,6 +226,7 @@ def _small_conducting_mie(m, x):
 
     return [qext, qsca, qback, g]
 
+
 def _small_mie(m, x):
     """
     Calculate the efficiencies for a small sphere.
@@ -237,13 +246,14 @@ def _small_mie(m, x):
     m2 = m * m
     x2 = x * x
 
-    D = m2 + 2 + (1 - 0.7 * m2) * x2 - (8 * m**4 - 385 * m2 + 350) * x**4 / 1400.0 + \
-        2j * (m2 - 1) * x**3 * (1 - 0.1 * x2) / 3
+    D = m2 + 2 + (1 - 0.7 * m2) * x2
+    D -= (8 * m**4 - 385 * m2 + 350) * x**4 / 1400.0
+    D += 2j * (m2 - 1) * x**3 * (1 - 0.1 * x2) / 3
     ahat1 = 2j * (m2 - 1) / 3 * (1 - 0.1 * x2 + (4 * m2 + 5) * x**4 / 1400) / D
-    bhat1 = 1j * x2 * (m2 - 1) / 45 * (1 + (2 * m2 - 5) /
-                                       70 * x2) / (1 - (2 * m2 - 5) / 30 * x2)
-    ahat2 = 1j * x2 * (m2 - 1) / 15 * (1 - x2 / 14) / \
-        (2 * m2 + 3 - (2 * m2 - 7) / 14 * x2)
+    bhat1 = 1j * x2 * (m2 - 1) / 45 * (1 + (2 * m2 - 5) / 70 * x2)
+    bhat1 /= 1 - (2 * m2 - 5) / 30 * x2
+    ahat2 = 1j * x2 * (m2 - 1) / 15 * (1 - x2 / 14)
+    ahat2 /= 2 * m2 + 3 - (2 * m2 - 7) / 14 * x2
 
     T = np.abs(ahat1)**2 + np.abs(bhat1)**2 + 5 / 3 * np.abs(ahat2)**2
     temp = ahat2 + bhat1
@@ -257,10 +267,11 @@ def _small_mie(m, x):
         qext = 6 * x * (ahat1 + bhat1 + 5 * ahat2 / 3).real
 
     sback = 1.5 * x**3 * (ahat1 - bhat1 - 5 * ahat2 / 3)
-    qback = 4*np.abs(sback)**2/x2
+    qback = 4 * np.abs(sback)**2 / x2
 
     return [qext, qsca, qback, g]
 
+
 def _mie_scalar(m, x):
     """
     Calculate the efficiencies for a sphere when both m and x are scalars.
@@ -276,10 +287,10 @@ def _mie_scalar(m, x):
         g: the average cosine of the scattering phase function
     """
     if m.real == 0 and x < 0.1:
-        qext, qsca, qback, g =_small_conducting_mie(m, x)
+        qext, qsca, qback, g = _small_conducting_mie(m, x)
 
     elif m.real > 0.0 and np.abs(m) * x < 0.1:
-        qext, qsca, qback, g =_small_mie(m, x)
+        qext, qsca, qback, g = _small_mie(m, x)
 
     else:
         nstop = int(x + 4.05 * x**0.33333 + 2.0) + 1
@@ -303,13 +314,14 @@ def _mie_scalar(m, x):
         c2n = cn / n / (n + 1)
         g = 0
         for i in range(nmax - 1):
-            asy1 = c1n[i] * (a[i] * a[i + 1].conjugate() +
-                             b[i] * b[i + 1].conjugate()).real
+            asy1 = c1n[i] * (a[i] * a[i + 1].conjugate()
+                             + b[i] * b[i + 1].conjugate()).real
             asy2 = c2n[i] * (a[i] * b[i].conjugate()).real
             g += 4 * (asy1 + asy2) / qsca / x**2
 
     return [qext, qsca, qback, g]
 
+
 def mie(m, x):
     """
     Calculate the efficiencies for a sphere where m or x may be arrays.
@@ -360,6 +372,7 @@ def mie(m, x):
 
     return qext, qsca, qback, g
 
+
 def _small_mie_conducting_S1_S2(m, x, mu):
     """
     Calculate the scattering amplitudes for small conducting spheres.
@@ -383,19 +396,26 @@ def _small_mie_conducting_S1_S2(m, x, mu):
     ahat2 = 1j / 30 * x**2
     bhat2 = -1j * x**2 / 45
 
-    S1 = 1.5 * x**3 * (ahat1 + bhat1 * mu + 5 / 3 * ahat2 *
-                       mu + 5 / 3 * bhat2 * (2 * mu**2 - 1))
-    S2 = 1.5 * x**3 * (bhat1 + ahat1 * mu + 5 / 3 * bhat2 *
-                       mu + 5 / 3 * ahat2 * (2 * mu**2 - 1))
+    S1 = 1.5 * x**3 * (ahat1 + bhat1 * mu
+                       + 5 / 3 * ahat2 * mu
+                       + 5 / 3 * bhat2 * (2 * mu**2 - 1))
+
+    S2 = 1.5 * x**3 * (bhat1 + ahat1 * mu
+                       + 5 / 3 * bhat2 * mu
+                       + 5 / 3 * ahat2 * (2 * mu**2 - 1))
+
+    qext = x**4 * (6 * np.abs(ahat1)**2
+                   + 6 * np.abs(bhat1)**2
+                   + 10 * np.abs(ahat2)**2
+                   + 10 * np.abs(bhat2)**2)
 
-    qext = x**4 * (6 * np.abs(ahat1)**2 + 6 * np.abs(bhat1)**2 + 10 * np.abs(ahat2)**2 +
-                   10 * np.abs(bhat2)**2)
     norm = np.sqrt(qext * np.pi * x**2)
     S1 /= norm
     S2 /= norm
 
     return [S1, S2]
 
+
 def _small_mie_S1_S2(m, x, mu):
     """
     Calculate the scattering amplitude functions for small spheres (x<0.1).
@@ -419,13 +439,17 @@ def _small_mie_S1_S2(m, x, mu):
     x3 = x2 * x
     x4 = x2 * x2
 
-    D = m2 + 2 + (1 - 0.7 * m2) * x2 - (8 * m4 - 385 * m2 + 350) * x4 / 1400.0 + \
-        2j * (m2 - 1) * x3 * (1 - 0.1 * x2) / 3
+    D = m2 + 2 + (1 - 0.7 * m2) * x2
+    D -= (8 * m4 - 385 * m2 + 350) * x4 / 1400.0
+    D += 2j * (m2 - 1) * x3 * (1 - 0.1 * x2) / 3
+
     ahat1 = 2j * (m2 - 1) / 3 * (1 - 0.1 * x2 + (4 * m2 + 5) * x4 / 1400) / D
-    bhat1 = 1j * x2 * (m2 - 1) / 45 * (1 + (2 * m2 - 5) /
-                                       70 * x2) / (1 - (2 * m2 - 5) / 30 * x2)
-    ahat2 = 1j * x2 * (m2 - 1) / 15 * (1 - x2 / 14) / \
-        (2 * m2 + 3 - (2 * m2 - 7) / 14 * x2)
+
+    bhat1 = 1j * x2 * (m2 - 1) / 45 * (1 + (2 * m2 - 5) / 70 * x2)
+    bhat1 /= 1 - (2 * m2 - 5) / 30 * x2
+
+    ahat2 = 1j * x2 * (m2 - 1) / 15 * (1 - x2 / 14)
+    ahat2 /= 2 * m2 + 3 - (2 * m2 - 7) / 14 * x2
 
     S1 = 1.5 * x3 * (ahat1 + bhat1 * mu + 5 / 3 * ahat2 * mu)
     S2 = 1.5 * x3 * (bhat1 + ahat1 * mu + 5 / 3 * ahat2 * (2 * mu**2 - 1))
@@ -437,6 +461,7 @@ def _small_mie_S1_S2(m, x, mu):
 
     return [S1, S2]
 
+
 def mie_S1_S2(m, x, mu):
     """
     Calculate the scattering amplitude functions for spheres.
@@ -469,10 +494,10 @@ def mie_S1_S2(m, x, mu):
         pi_nm1 = 1
         for n in range(1, nstop):
             tau_nm1 = n * mu[k] * pi_nm1 - (n + 1) * pi_nm2
-            S1[k] += (2 * n + 1) * (pi_nm1 * a[n - 1] +
-                                    tau_nm1 * b[n - 1]) / (n + 1) / n
-            S2[k] += (2 * n + 1) * (tau_nm1 * a[n - 1] +
-                                    pi_nm1 * b[n - 1]) / (n + 1) / n
+            S1[k] += (2 * n + 1) * (pi_nm1 * a[n - 1]
+                                    + tau_nm1 * b[n - 1]) / (n + 1) / n
+            S2[k] += (2 * n + 1) * (tau_nm1 * a[n - 1]
+                                    + pi_nm1 * b[n - 1]) / (n + 1) / n
 
             temp = pi_nm1
             pi_nm1 = ((2 * n + 1) * mu[k] * pi_nm1 - (n + 1) * pi_nm2) / n
@@ -487,6 +512,7 @@ def mie_S1_S2(m, x, mu):
 
     return [S1, S2]
 
+
 def mie_cdf(m, x, num):
     """
     Create a CDF for unpolarized scattering uniformly spaced in cos(theta).
@@ -523,6 +549,7 @@ def mie_cdf(m, x, num):
 
     return mu, cdf
 
+
 def mie_mu_with_uniform_cdf(m, x, num):
     """
     Create a CDF for unpolarized scattering for uniform CDF.
@@ -570,14 +597,15 @@ def mie_mu_with_uniform_cdf(m, x, num):
         mu[k] = big_mu[big_k] - delta / delta_cdf * delta_mu   # interpolate
         cdf[k] = target
 
-#       print(' mu[',k,']=% .5f'%mu[k],' cdf[',k,']=% .5f'%cdf[k],
-#       'cdf=',big_cdf[big_k], fraction)
+#       print(' mu[', k, ']=% .5f'%mu[k], ' cdf[', k, ']=% .5f'%cdf[k],
+#       'cdf=', big_cdf[big_k], fraction)
 
     mu[num - 1] = 1                    # cos[0 degrees] is 1
     cdf[num - 1] = 1                   # last cdf is one
 
     return [mu, cdf]
 
+
 def generate_mie_costheta(mu_cdf):
     """
     Generate a new scattering angle using a cdf.
@@ -605,6 +633,7 @@ def generate_mie_costheta(mu_cdf):
 
     return x
 
+
 def i_per(m, x, mu):
     """
     Return the scattered intensity in a plane normal to the incident light.
@@ -626,6 +655,7 @@ def i_per(m, x, mu):
     intensity = np.abs(s1)**2
     return intensity.astype('float')
 
+
 def i_par(m, x, mu):
     """
     Return the scattered intensity in a plane parallel to the incident light.
@@ -647,6 +677,7 @@ def i_par(m, x, mu):
     intensity = np.abs(s2)**2
     return intensity.astype('float')
 
+
 def i_unpolarized(m, x, mu):
     """
     Return the unpolarized scattered intensity at specified angles.
@@ -668,6 +699,7 @@ def i_unpolarized(m, x, mu):
     intensity = (np.abs(s1)**2 + np.abs(s2)**2) / 2
     return intensity.astype('float')
 
+
 def ez_mie(m, d, lambda0, n_env=1.0):
     """
     Calculate the efficiencies of a sphere.
@@ -685,9 +717,10 @@ def ez_mie(m, d, lambda0, n_env=1.0):
         g: the average cosine of the scattering phase function [-]
     """
     m_env = m / n_env
-    x_env = np.pi*d/(lambda0/n_env)
+    x_env = np.pi * d / (lambda0 / n_env)
     return mie(m_env, x_env)
 
+
 def ez_intensities(m, d, lambda0, mu, n_env=1.0):
     """
     Return the scattered intensities from a sphere.
@@ -713,7 +746,7 @@ def ez_intensities(m, d, lambda0, mu, n_env=1.0):
     """
     m_env = m / n_env
     lambda_env = lambda0 / n_env
-    x_env = np.pi*d/lambda_env
+    x_env = np.pi * d / lambda_env
     s1, s2 = mie_S1_S2(m_env, x_env, mu)
     ipar = np.abs(s2)**2
     iper = np.abs(s1)**2
